.. These are examples of badges you might want to add to your README:
   please update the URLs accordingly

    .. image:: https://img.shields.io/pypi/v/pH_diagrams.svg
        :alt: PyPI-Server
        :target: https://pypi.org/project/pH-diagrams/


.. image:: https://img.shields.io/badge/Author-Francisco%20Bustamante-red.svg
    :alt: Francisco Bustamante
    :target: https://www.linkedin.com/in/flsbustamante
.. image:: https://img.shields.io/badge/Python-3.8+-blue.svg
    :alt: Python
    :target: https://www.python.org/
.. image:: https://img.shields.io/badge/License-MIT-blue.svg
    :alt: LICENSE
    :target: LICENSE.txt
.. image:: https://img.shields.io/badge/Contributions-Welcome-brightgreen.svg?style=flat
    :alt: Contributions are welcome
    :target: https://github.com/chicolucio/pH-diagrams/issues
.. image:: https://img.shields.io/badge/-PyScaffold-005CA0?logo=pyscaffold
    :alt: Project generated with PyScaffold
    :target: https://pyscaffold.org/
.. image:: https://readthedocs.org/projects/ph-diagrams/badge/?version=latest
   :target: https://ph-diagrams.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status


===========
pH diagrams
===========

    A Python package to plot fractional composition diagrams and pH-log c diagrams

.. image:: https://github.com/chicolucio/pH-diagrams/blob/master/images/animation.gif?raw=true
    :alt: header animation
    :align: center

Installation
============

::

   pip install pH-diagrams

Usage
=====

Full documentation is hosted on `Read the Docs`_

For basic usage see the tutorial notebook on ``notebooks`` folder.

A live interactive version of this project can be seen clicking in the following badge:

.. image:: https://img.shields.io/badge/-Streamlit%20app-FF4B4B?style=for-the-badge&logo=Streamlit&logoColor=white
    :alt: Streamlit app
    :align: center
    :target: https://phdiagrams.herokuapp.com/

The web app was made with Streamlit_ and hosted on Heroku_.


Contributing
============

All contributions are welcome.

**Issues**

Feel free to submit issues regarding:

- recommendations
- more examples for the tutorial
- enhancement requests and new useful features
- code bugs

**Pull requests**

- before starting to work on your pull request, please submit an issue first
- fork the repo
- clone the project to your own machine
- commit changes to your own branch
- push your work back up to your fork
- submit a pull request so that your changes can be reviewed

For full contribution guidelines and details check out our `contributing guide`_.



Citing
======

If you use this project in a scientific publication or in classes, please consider citing as

F. L. S. Bustamante & H. B. Soares & N. O. Souza, pH diagrams, 2021.
Available at: https://github.com/chicolucio/pH-diagrams

.. _Streamlit: https://streamlit.io
.. _Heroku: https://www.heroku.com
.. _contributing guide: CONTRIBUTING.rst
.. _Read the Docs: https://ph-diagrams.readthedocs.io/en/latest/?badge=latest
